@@ -40,10 +40,6 @@ class Insider:
     def get_mapping(self, port):
         return self.port_mapper.get(port)
 
-    # TODO: Remove after owncloud-ctl migration to service_info
-    def service_urls(self, name):
-        return self.dns.service_urls(name)
-
     def service_info(self, name):
         return self.dns.service_info(name)
 
